@@ -97,6 +97,9 @@ pkg_digger
 pkg_micro_src_summary
 summary2multi_variants
 pkg_summary2bb_pkgs
+pkg_cleanup_dir
+pkg_cleanup_distdir
+pkg_cleanup_packages
 pkg_src_summary
 '
 
